Documentation
¶
Index ¶
- type Duration
- func (d Duration) Duration() time.Duration
- func (d Duration) MarshalJSON() ([]byte, error)
- func (d *Duration) PGInterval() pgtype.Interval
- func (d *Duration) Set(s string) error
- func (d Duration) String() string
- func (d *Duration) UnmarshalJSON(b []byte) error
- func (d *Duration) UnmarshalText(text []byte) error
- func (d *Duration) UnmarshalYAML(n *yaml.Node) error
- type Location
- type Metadata
- type String
- type Time
- func (t Time) MarshalJSON() ([]byte, error)
- func (t *Time) PGTypeTSTZ() pgtype.Timestamptz
- func (t *Time) Set(s string) error
- func (t *Time) String() string
- func (t Time) Time() time.Time
- func (t *Time) Type() string
- func (t *Time) UnmarshalJSON(b []byte) error
- func (t *Time) UnmarshalYAML(n *yaml.Node) error
- type URL
- type UUID
- type UUIDs
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Duration ¶
func ParseDuration ¶
func (Duration) MarshalJSON ¶
func (*Duration) PGInterval ¶
func (*Duration) UnmarshalJSON ¶
func (*Duration) UnmarshalText ¶
type Location ¶
type Location struct {
json.RawMessage
}
type String ¶
type String string
This type is used when we should unmarshal even values that are valid as another type into a string.
func (*String) UnmarshalJSON ¶
type Time ¶
func ParseLocal ¶
func ParseLocal(s string, opt ...dateparse.ParserOption) (Time, error)
func TimePtrFromTSTZ ¶
func TimePtrFromTSTZ(t pgtype.Timestamptz) *Time
func (Time) MarshalJSON ¶
func (*Time) PGTypeTSTZ ¶
func (t *Time) PGTypeTSTZ() pgtype.Timestamptz
func (*Time) UnmarshalJSON ¶
Click to show internal directories.
Click to hide internal directories.