package
Version:
v0.0.0-...-1a3a2fa
Opens a new window with list of versions in this module.
Published: Jun 11, 2026
License: BSD-3-Clause
Opens a new window with license information.
Imports: 2
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
Package services avoids having to wrap contexts so much for multiple services.
type Services interface {
Set(key, val any)
Value(key any) any
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.