Discover Packages
dynatron.me/x/stillbox
pkg
talkgroups
xport
package
Version:
v0.0.0-...-1a3a2fa
Opens a new window with list of versions in this module.
Published: Jun 11, 2026
License: BSD-3-Clause
Opens a new window with license information.
Imports: 9
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
Documentation
¶
type ExportJob struct {
Type Format `json:"type" form:"type"`
SystemID int `json:"systemID" form:"systemID"`
Template []byte `json:"template" form:"template" filenameField:"TemplateFileName"`
TemplateFileName string
filter .Filter
Exporter
}
const (
FormatRadioReference Format = "radioreference"
FormatSDRTrunk Format = "sdrtrunk"
)
type ImportJob struct {
Type Format `json:"type"`
SystemID int `json:"systemID"`
Body string `json:"body"`
Importer `json:"-"`
}
Source Files
¶
Directories
¶
Click to show internal directories.
Click to hide internal directories.