Documentation
¶
Index ¶
- Variables
- type Call
- func (*Call) Descriptor() ([]byte, []int)deprecated
- func (x *Call) GetAudio() []byte
- func (x *Call) GetAudioName() string
- func (x *Call) GetAudioType() string
- func (x *Call) GetDateTime() *timestamppb.Timestamp
- func (x *Call) GetDuration() int32
- func (x *Call) GetFrequencies() []int64
- func (x *Call) GetFrequency() int64
- func (x *Call) GetId() string
- func (x *Call) GetPatches() []int32
- func (x *Call) GetSource() int32
- func (x *Call) GetSystem() int32
- func (x *Call) GetTalkerAlias() string
- func (x *Call) GetTalkgroup() int32
- func (*Call) ProtoMessage()
- func (x *Call) ProtoReflect() protoreflect.Message
- func (x *Call) Reset()
- func (x *Call) String() string
- type CallTranscription
- func (*CallTranscription) Descriptor() ([]byte, []int)deprecated
- func (x *CallTranscription) GetId() string
- func (x *CallTranscription) GetPatches() []int32
- func (x *CallTranscription) GetSystem() int32
- func (x *CallTranscription) GetTalkgroup() int32
- func (x *CallTranscription) GetTranscript() string
- func (*CallTranscription) ProtoMessage()
- func (x *CallTranscription) ProtoReflect() protoreflect.Message
- func (x *CallTranscription) Reset()
- func (x *CallTranscription) String() string
- type Command
- func (*Command) Descriptor() ([]byte, []int)deprecated
- func (x *Command) GetCommand() isCommand_Command
- func (x *Command) GetCommandId() int64
- func (x *Command) GetLiveCommand() *Live
- func (x *Command) GetRegisterCommand() *Register
- func (x *Command) GetSearchCommand() *Search
- func (x *Command) GetSetTranscript() *SetTranscript
- func (x *Command) GetTgCommand() *Talkgroup
- func (*Command) ProtoMessage()
- func (x *Command) ProtoReflect() protoreflect.Message
- func (x *Command) Reset()
- func (x *Command) String() string
- type CommandResponse
- func (*CommandResponse) Descriptor() ([]byte, []int)deprecated
- func (x *CommandResponse) GetCommandId() int64
- func (x *CommandResponse) GetCommandResponse() isCommandResponse_CommandResponse
- func (x *CommandResponse) GetTgInfo() *TalkgroupInfo
- func (*CommandResponse) ProtoMessage()
- func (x *CommandResponse) ProtoReflect() protoreflect.Message
- func (x *CommandResponse) Reset()
- func (x *CommandResponse) String() string
- type CommandResponse_TgInfo
- type Command_LiveCommand
- type Command_RegisterCommand
- type Command_SearchCommand
- type Command_SetTranscript
- type Command_TgCommand
- type Error
- type Filter
- func (*Filter) Descriptor() ([]byte, []int)deprecated
- func (x *Filter) GetAll() bool
- func (x *Filter) GetTalkgroupTagsAll() []string
- func (x *Filter) GetTalkgroupTagsAny() []string
- func (x *Filter) GetTalkgroupTagsNot() []string
- func (x *Filter) GetTalkgroups() []*Talkgroup
- func (x *Filter) GetTalkgroupsNot() []*Talkgroup
- func (*Filter) ProtoMessage()
- func (x *Filter) ProtoReflect() protoreflect.Message
- func (x *Filter) Reset()
- func (x *Filter) String() string
- type Hello
- type Live
- func (*Live) Descriptor() ([]byte, []int)deprecated
- func (x *Live) GetCalls() bool
- func (x *Live) GetFilter() *Filter
- func (x *Live) GetState() LiveState
- func (x *Live) GetTranscripts() bool
- func (*Live) ProtoMessage()
- func (x *Live) ProtoReflect() protoreflect.Message
- func (x *Live) Reset()
- func (x *Live) String() string
- type LiveState
- type Message
- func (*Message) Descriptor() ([]byte, []int)deprecated
- func (x *Message) GetCall() *Call
- func (x *Message) GetError() *Error
- func (x *Message) GetHello() *Hello
- func (x *Message) GetNotification() *Notification
- func (x *Message) GetPopup() *UserPopup
- func (x *Message) GetResponse() *CommandResponse
- func (x *Message) GetToClientMessage() isMessage_ToClientMessage
- func (x *Message) GetTranscription() *CallTranscription
- func (*Message) ProtoMessage()
- func (x *Message) ProtoReflect() protoreflect.Message
- func (x *Message) Reset()
- func (x *Message) String() string
- type Message_Call
- type Message_Error
- type Message_Hello
- type Message_Notification
- type Message_Popup
- type Message_Response
- type Message_Transcription
- type Notification
- func (*Notification) Descriptor() ([]byte, []int)deprecated
- func (x *Notification) GetActionUrl() string
- func (x *Notification) GetDateTime() *timestamppb.Timestamp
- func (x *Notification) GetMsg() string
- func (x *Notification) GetTitle() string
- func (*Notification) ProtoMessage()
- func (x *Notification) ProtoReflect() protoreflect.Message
- func (x *Notification) Reset()
- func (x *Notification) String() string
- type Register
- type Search
- type ServerInfo
- func (*ServerInfo) Descriptor() ([]byte, []int)deprecated
- func (x *ServerInfo) GetBuilt() string
- func (x *ServerInfo) GetDbSize() string
- func (x *ServerInfo) GetPlatform() string
- func (x *ServerInfo) GetServerName() string
- func (x *ServerInfo) GetVersion() string
- func (*ServerInfo) ProtoMessage()
- func (x *ServerInfo) ProtoReflect() protoreflect.Message
- func (x *ServerInfo) Reset()
- func (x *ServerInfo) String() string
- type SetTranscript
- func (*SetTranscript) Descriptor() ([]byte, []int)deprecated
- func (x *SetTranscript) GetElapsedMs() int64
- func (x *SetTranscript) GetId() string
- func (x *SetTranscript) GetTranscript() string
- func (*SetTranscript) ProtoMessage()
- func (x *SetTranscript) ProtoReflect() protoreflect.Message
- func (x *SetTranscript) Reset()
- func (x *SetTranscript) String() string
- type Talkgroup
- type TalkgroupInfo
- func (*TalkgroupInfo) Descriptor() ([]byte, []int)deprecated
- func (x *TalkgroupInfo) GetAlphaTag() string
- func (x *TalkgroupInfo) GetFrequency() int32
- func (x *TalkgroupInfo) GetGroup() string
- func (x *TalkgroupInfo) GetLearned() bool
- func (x *TalkgroupInfo) GetMetadata() *structpb.Struct
- func (x *TalkgroupInfo) GetName() string
- func (x *TalkgroupInfo) GetSystemName() string
- func (x *TalkgroupInfo) GetTags() []string
- func (x *TalkgroupInfo) GetTg() *Talkgroup
- func (*TalkgroupInfo) ProtoMessage()
- func (x *TalkgroupInfo) ProtoReflect() protoreflect.Message
- func (x *TalkgroupInfo) Reset()
- func (x *TalkgroupInfo) String() string
- type UserPopup
Constants ¶
This section is empty.
Variables ¶
var ( LiveState_name = map[int32]string{ 0: "LS_STOPPED", 1: "LS_LIVE", 2: "LS_PAUSED", } LiveState_value = map[string]int32{ "LS_STOPPED": 0, "LS_LIVE": 1, "LS_PAUSED": 2, } )
Enum value maps for LiveState.
var File_stillbox_proto protoreflect.FileDescriptor
Functions ¶
This section is empty.
Types ¶
type Call ¶
type Call struct {
Id string `protobuf:"bytes,1,opt,name=id,proto3" json:"id,omitempty"`
AudioName string `protobuf:"bytes,2,opt,name=audioName,proto3" json:"audioName,omitempty"`
AudioType string `protobuf:"bytes,3,opt,name=audioType,proto3" json:"audioType,omitempty"`
DateTime *timestamppb.Timestamp `protobuf:"bytes,4,opt,name=date_time,json=dateTime,proto3" json:"date_time,omitempty"`
System int32 `protobuf:"varint,5,opt,name=system,proto3" json:"system,omitempty"`
Talkgroup int32 `protobuf:"varint,6,opt,name=talkgroup,proto3" json:"talkgroup,omitempty"`
TalkerAlias *string `protobuf:"bytes,7,opt,name=talker_alias,json=talkerAlias,proto3,oneof" json:"talker_alias,omitempty"`
Source int32 `protobuf:"varint,8,opt,name=source,proto3" json:"source,omitempty"`
Frequency int64 `protobuf:"varint,9,opt,name=frequency,proto3" json:"frequency,omitempty"`
Frequencies []int64 `protobuf:"varint,10,rep,packed,name=frequencies,proto3" json:"frequencies,omitempty"`
Patches []int32 `protobuf:"varint,11,rep,packed,name=patches,proto3" json:"patches,omitempty"`
Duration *int32 `protobuf:"varint,12,opt,name=duration,proto3,oneof" json:"duration,omitempty"`
Audio []byte `protobuf:"bytes,13,opt,name=audio,proto3" json:"audio,omitempty"`
// contains filtered or unexported fields
}
func (*Call) Descriptor
deprecated
func (*Call) GetAudioName ¶
func (*Call) GetAudioType ¶
func (*Call) GetDateTime ¶
func (x *Call) GetDateTime() *timestamppb.Timestamp
func (*Call) GetDuration ¶
func (*Call) GetFrequencies ¶
func (*Call) GetFrequency ¶
func (*Call) GetPatches ¶
func (*Call) GetTalkerAlias ¶
func (*Call) GetTalkgroup ¶
func (*Call) ProtoMessage ¶
func (*Call) ProtoMessage()
func (*Call) ProtoReflect ¶
func (x *Call) ProtoReflect() protoreflect.Message
type CallTranscription ¶
type CallTranscription struct {
Id string `protobuf:"bytes,1,opt,name=id,proto3" json:"id,omitempty"`
System int32 `protobuf:"varint,2,opt,name=system,proto3" json:"system,omitempty"`
Talkgroup int32 `protobuf:"varint,3,opt,name=talkgroup,proto3" json:"talkgroup,omitempty"`
Patches []int32 `protobuf:"varint,4,rep,packed,name=patches,proto3" json:"patches,omitempty"`
Transcript string `protobuf:"bytes,5,opt,name=transcript,proto3" json:"transcript,omitempty"`
// contains filtered or unexported fields
}
func (*CallTranscription) Descriptor
deprecated
func (*CallTranscription) Descriptor() ([]byte, []int)
Deprecated: Use CallTranscription.ProtoReflect.Descriptor instead.
func (*CallTranscription) GetId ¶
func (x *CallTranscription) GetId() string
func (*CallTranscription) GetPatches ¶
func (x *CallTranscription) GetPatches() []int32
func (*CallTranscription) GetSystem ¶
func (x *CallTranscription) GetSystem() int32
func (*CallTranscription) GetTalkgroup ¶
func (x *CallTranscription) GetTalkgroup() int32
func (*CallTranscription) GetTranscript ¶
func (x *CallTranscription) GetTranscript() string
func (*CallTranscription) ProtoMessage ¶
func (*CallTranscription) ProtoMessage()
func (*CallTranscription) ProtoReflect ¶
func (x *CallTranscription) ProtoReflect() protoreflect.Message
func (*CallTranscription) Reset ¶
func (x *CallTranscription) Reset()
func (*CallTranscription) String ¶
func (x *CallTranscription) String() string
type Command ¶
type Command struct {
CommandId *int64 `protobuf:"varint,1,opt,name=command_id,json=commandId,proto3,oneof" json:"command_id,omitempty"`
// Types that are valid to be assigned to Command:
//
// *Command_LiveCommand
// *Command_SearchCommand
// *Command_TgCommand
// *Command_RegisterCommand
// *Command_SetTranscript
Command isCommand_Command `protobuf_oneof:"command"`
// contains filtered or unexported fields
}
func (*Command) Descriptor
deprecated
func (*Command) GetCommand ¶
func (x *Command) GetCommand() isCommand_Command
func (*Command) GetCommandId ¶
func (*Command) GetLiveCommand ¶
func (*Command) GetRegisterCommand ¶
func (*Command) GetSearchCommand ¶
func (*Command) GetSetTranscript ¶
func (x *Command) GetSetTranscript() *SetTranscript
func (*Command) GetTgCommand ¶
func (*Command) ProtoMessage ¶
func (*Command) ProtoMessage()
func (*Command) ProtoReflect ¶
func (x *Command) ProtoReflect() protoreflect.Message
type CommandResponse ¶
type CommandResponse struct {
CommandId *int64 `protobuf:"varint,1,opt,name=command_id,json=commandId,proto3,oneof" json:"command_id,omitempty"`
// Types that are valid to be assigned to CommandResponse:
//
// *CommandResponse_TgInfo
CommandResponse isCommandResponse_CommandResponse `protobuf_oneof:"command_response"`
// contains filtered or unexported fields
}
func (*CommandResponse) Descriptor
deprecated
func (*CommandResponse) Descriptor() ([]byte, []int)
Deprecated: Use CommandResponse.ProtoReflect.Descriptor instead.
func (*CommandResponse) GetCommandId ¶
func (x *CommandResponse) GetCommandId() int64
func (*CommandResponse) GetCommandResponse ¶
func (x *CommandResponse) GetCommandResponse() isCommandResponse_CommandResponse
func (*CommandResponse) GetTgInfo ¶
func (x *CommandResponse) GetTgInfo() *TalkgroupInfo
func (*CommandResponse) ProtoMessage ¶
func (*CommandResponse) ProtoMessage()
func (*CommandResponse) ProtoReflect ¶
func (x *CommandResponse) ProtoReflect() protoreflect.Message
func (*CommandResponse) Reset ¶
func (x *CommandResponse) Reset()
func (*CommandResponse) String ¶
func (x *CommandResponse) String() string
type CommandResponse_TgInfo ¶
type CommandResponse_TgInfo struct {
TgInfo *TalkgroupInfo `protobuf:"bytes,2,opt,name=tg_info,json=tgInfo,proto3,oneof"`
}
type Command_LiveCommand ¶
type Command_LiveCommand struct {
LiveCommand *Live `protobuf:"bytes,2,opt,name=live_command,json=liveCommand,proto3,oneof"`
}
type Command_RegisterCommand ¶
type Command_RegisterCommand struct {
RegisterCommand *Register `protobuf:"bytes,5,opt,name=register_command,json=registerCommand,proto3,oneof"`
}
type Command_SearchCommand ¶
type Command_SearchCommand struct {
SearchCommand *Search `protobuf:"bytes,3,opt,name=search_command,json=searchCommand,proto3,oneof"`
}
type Command_SetTranscript ¶
type Command_SetTranscript struct {
SetTranscript *SetTranscript `protobuf:"bytes,6,opt,name=set_transcript,json=setTranscript,proto3,oneof"`
}
type Command_TgCommand ¶
type Command_TgCommand struct {
TgCommand *Talkgroup `protobuf:"bytes,4,opt,name=tg_command,json=tgCommand,proto3,oneof"`
}
type Error ¶
type Error struct {
Error string `protobuf:"bytes,1,opt,name=error,proto3" json:"error,omitempty"`
Command *Command `protobuf:"bytes,2,opt,name=command,proto3" json:"command,omitempty"`
// contains filtered or unexported fields
}
func (*Error) Descriptor
deprecated
func (*Error) GetCommand ¶
func (*Error) ProtoMessage ¶
func (*Error) ProtoMessage()
func (*Error) ProtoReflect ¶
func (x *Error) ProtoReflect() protoreflect.Message
type Filter ¶
type Filter struct {
Talkgroups []*Talkgroup `protobuf:"bytes,1,rep,name=talkgroups,proto3" json:"talkgroups,omitempty"`
TalkgroupsNot []*Talkgroup `protobuf:"bytes,2,rep,name=talkgroups_not,json=talkgroupsNot,proto3" json:"talkgroups_not,omitempty"`
TalkgroupTagsAll []string `protobuf:"bytes,3,rep,name=talkgroup_tags_all,json=talkgroupTagsAll,proto3" json:"talkgroup_tags_all,omitempty"`
TalkgroupTagsAny []string `protobuf:"bytes,4,rep,name=talkgroup_tags_any,json=talkgroupTagsAny,proto3" json:"talkgroup_tags_any,omitempty"`
TalkgroupTagsNot []string `protobuf:"bytes,5,rep,name=talkgroup_tags_not,json=talkgroupTagsNot,proto3" json:"talkgroup_tags_not,omitempty"`
All bool `protobuf:"varint,6,opt,name=all,proto3" json:"all,omitempty"`
// contains filtered or unexported fields
}
func (*Filter) Descriptor
deprecated
func (*Filter) GetTalkgroupTagsAll ¶
func (*Filter) GetTalkgroupTagsAny ¶
func (*Filter) GetTalkgroupTagsNot ¶
func (*Filter) GetTalkgroups ¶
func (*Filter) GetTalkgroupsNot ¶
func (*Filter) ProtoMessage ¶
func (*Filter) ProtoMessage()
func (*Filter) ProtoReflect ¶
func (x *Filter) ProtoReflect() protoreflect.Message
type Hello ¶
type Hello struct {
ServerInfo *ServerInfo `protobuf:"bytes,1,opt,name=server_info,json=serverInfo,proto3" json:"server_info,omitempty"`
// contains filtered or unexported fields
}
func (*Hello) Descriptor
deprecated
func (*Hello) GetServerInfo ¶
func (x *Hello) GetServerInfo() *ServerInfo
func (*Hello) ProtoMessage ¶
func (*Hello) ProtoMessage()
func (*Hello) ProtoReflect ¶
func (x *Hello) ProtoReflect() protoreflect.Message
type Live ¶
type Live struct {
State *LiveState `protobuf:"varint,1,opt,name=state,proto3,enum=stillbox.LiveState,oneof" json:"state,omitempty"`
Filter *Filter `protobuf:"bytes,2,opt,name=filter,proto3,oneof" json:"filter,omitempty"`
Calls bool `protobuf:"varint,3,opt,name=calls,proto3" json:"calls,omitempty"`
Transcripts bool `protobuf:"varint,4,opt,name=transcripts,proto3" json:"transcripts,omitempty"`
// contains filtered or unexported fields
}
func (*Live) Descriptor
deprecated
func (*Live) GetTranscripts ¶
func (*Live) ProtoMessage ¶
func (*Live) ProtoMessage()
func (*Live) ProtoReflect ¶
func (x *Live) ProtoReflect() protoreflect.Message
type LiveState ¶
type LiveState int32
func (LiveState) Descriptor ¶
func (LiveState) Descriptor() protoreflect.EnumDescriptor
func (LiveState) EnumDescriptor
deprecated
func (LiveState) Number ¶
func (x LiveState) Number() protoreflect.EnumNumber
func (LiveState) Type ¶
func (LiveState) Type() protoreflect.EnumType
type Message ¶
type Message struct {
// Types that are valid to be assigned to ToClientMessage:
//
// *Message_Response
// *Message_Call
// *Message_Transcription
// *Message_Notification
// *Message_Popup
// *Message_Error
// *Message_Hello
ToClientMessage isMessage_ToClientMessage `protobuf_oneof:"toClient_message"`
// contains filtered or unexported fields
}
func (*Message) Descriptor
deprecated
func (*Message) GetNotification ¶
func (x *Message) GetNotification() *Notification
func (*Message) GetResponse ¶
func (x *Message) GetResponse() *CommandResponse
func (*Message) GetToClientMessage ¶
func (x *Message) GetToClientMessage() isMessage_ToClientMessage
func (*Message) GetTranscription ¶
func (x *Message) GetTranscription() *CallTranscription
func (*Message) ProtoMessage ¶
func (*Message) ProtoMessage()
func (*Message) ProtoReflect ¶
func (x *Message) ProtoReflect() protoreflect.Message
type Message_Call ¶
type Message_Call struct {
Call *Call `protobuf:"bytes,2,opt,name=call,proto3,oneof"`
}
type Message_Error ¶
type Message_Error struct {
Error *Error `protobuf:"bytes,6,opt,name=error,proto3,oneof"`
}
type Message_Hello ¶
type Message_Hello struct {
Hello *Hello `protobuf:"bytes,7,opt,name=hello,proto3,oneof"`
}
type Message_Notification ¶
type Message_Notification struct {
Notification *Notification `protobuf:"bytes,4,opt,name=notification,proto3,oneof"`
}
type Message_Popup ¶
type Message_Popup struct {
Popup *UserPopup `protobuf:"bytes,5,opt,name=popup,proto3,oneof"`
}
type Message_Response ¶
type Message_Response struct {
Response *CommandResponse `protobuf:"bytes,1,opt,name=response,proto3,oneof"`
}
type Message_Transcription ¶
type Message_Transcription struct {
Transcription *CallTranscription `protobuf:"bytes,3,opt,name=transcription,proto3,oneof"`
}
type Notification ¶
type Notification struct {
DateTime *timestamppb.Timestamp `protobuf:"bytes,1,opt,name=date_time,json=dateTime,proto3" json:"date_time,omitempty"`
Title string `protobuf:"bytes,2,opt,name=title,proto3" json:"title,omitempty"`
Msg string `protobuf:"bytes,3,opt,name=msg,proto3" json:"msg,omitempty"`
ActionUrl string `protobuf:"bytes,4,opt,name=action_url,json=actionUrl,proto3" json:"action_url,omitempty"`
// contains filtered or unexported fields
}
func (*Notification) Descriptor
deprecated
func (*Notification) Descriptor() ([]byte, []int)
Deprecated: Use Notification.ProtoReflect.Descriptor instead.
func (*Notification) GetActionUrl ¶
func (x *Notification) GetActionUrl() string
func (*Notification) GetDateTime ¶
func (x *Notification) GetDateTime() *timestamppb.Timestamp
func (*Notification) GetMsg ¶
func (x *Notification) GetMsg() string
func (*Notification) GetTitle ¶
func (x *Notification) GetTitle() string
func (*Notification) ProtoMessage ¶
func (*Notification) ProtoMessage()
func (*Notification) ProtoReflect ¶
func (x *Notification) ProtoReflect() protoreflect.Message
func (*Notification) Reset ¶
func (x *Notification) Reset()
func (*Notification) String ¶
func (x *Notification) String() string
type Register ¶
type Register struct {
TranscriptWorker bool `protobuf:"varint,1,opt,name=transcript_worker,json=transcriptWorker,proto3" json:"transcript_worker,omitempty"`
WorkerKey string `protobuf:"bytes,2,opt,name=worker_key,json=workerKey,proto3" json:"worker_key,omitempty"`
// contains filtered or unexported fields
}
func (*Register) Descriptor
deprecated
func (*Register) GetTranscriptWorker ¶
func (*Register) GetWorkerKey ¶
func (*Register) ProtoMessage ¶
func (*Register) ProtoMessage()
func (*Register) ProtoReflect ¶
func (x *Register) ProtoReflect() protoreflect.Message
type Search ¶
type Search struct {
// contains filtered or unexported fields
}
func (*Search) Descriptor
deprecated
func (*Search) ProtoMessage ¶
func (*Search) ProtoMessage()
func (*Search) ProtoReflect ¶
func (x *Search) ProtoReflect() protoreflect.Message
type ServerInfo ¶
type ServerInfo struct {
ServerName string `protobuf:"bytes,1,opt,name=server_name,json=serverName,proto3" json:"server_name,omitempty"`
Version string `protobuf:"bytes,2,opt,name=version,proto3" json:"version,omitempty"`
Built string `protobuf:"bytes,3,opt,name=built,proto3" json:"built,omitempty"`
Platform string `protobuf:"bytes,4,opt,name=platform,proto3" json:"platform,omitempty"`
DbSize string `protobuf:"bytes,5,opt,name=db_size,json=dbSize,proto3" json:"db_size,omitempty"`
// contains filtered or unexported fields
}
func (*ServerInfo) Descriptor
deprecated
func (*ServerInfo) Descriptor() ([]byte, []int)
Deprecated: Use ServerInfo.ProtoReflect.Descriptor instead.
func (*ServerInfo) GetBuilt ¶
func (x *ServerInfo) GetBuilt() string
func (*ServerInfo) GetDbSize ¶
func (x *ServerInfo) GetDbSize() string
func (*ServerInfo) GetPlatform ¶
func (x *ServerInfo) GetPlatform() string
func (*ServerInfo) GetServerName ¶
func (x *ServerInfo) GetServerName() string
func (*ServerInfo) GetVersion ¶
func (x *ServerInfo) GetVersion() string
func (*ServerInfo) ProtoMessage ¶
func (*ServerInfo) ProtoMessage()
func (*ServerInfo) ProtoReflect ¶
func (x *ServerInfo) ProtoReflect() protoreflect.Message
func (*ServerInfo) Reset ¶
func (x *ServerInfo) Reset()
func (*ServerInfo) String ¶
func (x *ServerInfo) String() string
type SetTranscript ¶
type SetTranscript struct {
Id string `protobuf:"bytes,1,opt,name=id,proto3" json:"id,omitempty"`
Transcript string `protobuf:"bytes,2,opt,name=transcript,proto3" json:"transcript,omitempty"`
ElapsedMs *int64 `protobuf:"varint,3,opt,name=elapsed_ms,json=elapsedMs,proto3,oneof" json:"elapsed_ms,omitempty"`
// contains filtered or unexported fields
}
func (*SetTranscript) Descriptor
deprecated
func (*SetTranscript) Descriptor() ([]byte, []int)
Deprecated: Use SetTranscript.ProtoReflect.Descriptor instead.
func (*SetTranscript) GetElapsedMs ¶
func (x *SetTranscript) GetElapsedMs() int64
func (*SetTranscript) GetId ¶
func (x *SetTranscript) GetId() string
func (*SetTranscript) GetTranscript ¶
func (x *SetTranscript) GetTranscript() string
func (*SetTranscript) ProtoMessage ¶
func (*SetTranscript) ProtoMessage()
func (*SetTranscript) ProtoReflect ¶
func (x *SetTranscript) ProtoReflect() protoreflect.Message
func (*SetTranscript) Reset ¶
func (x *SetTranscript) Reset()
func (*SetTranscript) String ¶
func (x *SetTranscript) String() string
type Talkgroup ¶
type Talkgroup struct {
System int32 `protobuf:"varint,1,opt,name=system,proto3" json:"system,omitempty"`
Talkgroup int32 `protobuf:"varint,2,opt,name=talkgroup,proto3" json:"talkgroup,omitempty"`
// contains filtered or unexported fields
}
func (*Talkgroup) Descriptor
deprecated
func (*Talkgroup) GetTalkgroup ¶
func (*Talkgroup) ProtoMessage ¶
func (*Talkgroup) ProtoMessage()
func (*Talkgroup) ProtoReflect ¶
func (x *Talkgroup) ProtoReflect() protoreflect.Message
type TalkgroupInfo ¶
type TalkgroupInfo struct {
Tg *Talkgroup `protobuf:"bytes,1,opt,name=tg,proto3" json:"tg,omitempty"`
SystemName string `protobuf:"bytes,2,opt,name=system_name,json=systemName,proto3" json:"system_name,omitempty"`
Name *string `protobuf:"bytes,3,opt,name=name,proto3,oneof" json:"name,omitempty"`
Group *string `protobuf:"bytes,4,opt,name=group,proto3,oneof" json:"group,omitempty"`
AlphaTag *string `protobuf:"bytes,5,opt,name=alpha_tag,json=alphaTag,proto3,oneof" json:"alpha_tag,omitempty"`
Frequency *int32 `protobuf:"varint,6,opt,name=frequency,proto3,oneof" json:"frequency,omitempty"`
Tags []string `protobuf:"bytes,7,rep,name=tags,proto3" json:"tags,omitempty"`
Metadata *structpb.Struct `protobuf:"bytes,8,opt,name=metadata,proto3,oneof" json:"metadata,omitempty"`
Learned bool `protobuf:"varint,9,opt,name=learned,proto3" json:"learned,omitempty"`
// contains filtered or unexported fields
}
func (*TalkgroupInfo) Descriptor
deprecated
func (*TalkgroupInfo) Descriptor() ([]byte, []int)
Deprecated: Use TalkgroupInfo.ProtoReflect.Descriptor instead.
func (*TalkgroupInfo) GetAlphaTag ¶
func (x *TalkgroupInfo) GetAlphaTag() string
func (*TalkgroupInfo) GetFrequency ¶
func (x *TalkgroupInfo) GetFrequency() int32
func (*TalkgroupInfo) GetGroup ¶
func (x *TalkgroupInfo) GetGroup() string
func (*TalkgroupInfo) GetLearned ¶
func (x *TalkgroupInfo) GetLearned() bool
func (*TalkgroupInfo) GetMetadata ¶
func (x *TalkgroupInfo) GetMetadata() *structpb.Struct
func (*TalkgroupInfo) GetName ¶
func (x *TalkgroupInfo) GetName() string
func (*TalkgroupInfo) GetSystemName ¶
func (x *TalkgroupInfo) GetSystemName() string
func (*TalkgroupInfo) GetTags ¶
func (x *TalkgroupInfo) GetTags() []string
func (*TalkgroupInfo) GetTg ¶
func (x *TalkgroupInfo) GetTg() *Talkgroup
func (*TalkgroupInfo) ProtoMessage ¶
func (*TalkgroupInfo) ProtoMessage()
func (*TalkgroupInfo) ProtoReflect ¶
func (x *TalkgroupInfo) ProtoReflect() protoreflect.Message
func (*TalkgroupInfo) Reset ¶
func (x *TalkgroupInfo) Reset()
func (*TalkgroupInfo) String ¶
func (x *TalkgroupInfo) String() string
type UserPopup ¶
type UserPopup struct {
Msg string `protobuf:"bytes,1,opt,name=msg,proto3" json:"msg,omitempty"`
// contains filtered or unexported fields
}
func (*UserPopup) Descriptor
deprecated
func (*UserPopup) ProtoMessage ¶
func (*UserPopup) ProtoMessage()
func (*UserPopup) ProtoReflect ¶
func (x *UserPopup) ProtoReflect() protoreflect.Message
Click to show internal directories.
Click to hide internal directories.